@@ -61,7 +61,8 @@ Binomial <- R6Class("Binomial",
     #' The arithmetic mean of a (discrete) probability distribution X is the expectation
     #' \deqn{E_X(X) = \sum p_X(x)*x}
     #' with an integration analogue for continuous distributions.
-    mean = function() {
+    #' @param ... Unused.
+    mean = function(...) {
       unlist(self$getParameterValue("size")) * unlist(self$getParameterValue("prob"))
     },
 
@@ -79,7 +80,8 @@ Binomial <- R6Class("Binomial",
     #' \deqn{var_X = E[X^2] - E[X]^2}
     #' where \eqn{E_X} is the expectation of distribution X. If the distribution is multivariate the
     #' covariance matrix is returned.
-    variance = function() {
+    #' @param ... Unused.
+    variance = function(...) {
       prob <- unlist(self$getParameterValue("prob"))
       qprob <- 1 - prob
 
@@ -91,7 +93,8 @@ Binomial <- R6Class("Binomial",
     #' \deqn{sk_X = E_X[\frac{x - \mu}{\sigma}^3]}{sk_X = E_X[((x - \mu)/\sigma)^3]}
     #' where \eqn{E_X} is the expectation of distribution X, \eqn{\mu} is the mean of the
     #' distribution and \eqn{\sigma} is the standard deviation of the distribution.
-    skewness = function() {
+    #' @param ... Unused.
+    skewness = function(...) {
       (1 - (2 * unlist(self$getParameterValue("prob")))) / self$stdev()
     },
 
@@ -101,7 +104,8 @@ Binomial <- R6Class("Binomial",
     #' where \eqn{E_X} is the expectation of distribution X, \eqn{\mu} is the mean of the
     #' distribution and \eqn{\sigma} is the standard deviation of the distribution.
     #' Excess Kurtosis is Kurtosis - 3.
-    kurtosis = function(excess = TRUE) {
+    #' @param ... Unused.
+    kurtosis = function(excess = TRUE, ...) {
       prob <- unlist(self$getParameterValue("prob"))
       exkurtosis <- (1 - (6 * prob * (1 - prob))) / self$variance()
       if (excess) {
@@ -116,14 +120,16 @@ Binomial <- R6Class("Binomial",
     #' \deqn{- \sum (f_X)log(f_X)}
     #' where \eqn{f_X} is the pdf of distribution X, with an integration analogue for
     #' continuous distributions.
-    entropy = function(base = 2) {
+    #' @param ... Unused.
+    entropy = function(base = 2, ...) {
       0.5 * log(2 * pi * exp(1) * self$variance(), base)
     },
 
     #' @description The moment generating function is defined by
     #' \deqn{mgf_X(t) = E_X[exp(xt)]}
     #' where X is the distribution and \eqn{E_X} is the expectation of the distribution X.
-    mgf = function(t) {
+    #' @param ... Unused.
+    mgf = function(t, ...) {
       (self$getParameterValue("qprob") +
         (self$getParameterValue("prob") * exp(t)))^self$getParameterValue("size")
     },
@@ -131,7 +137,8 @@ Binomial <- R6Class("Binomial",
     #' @description The characteristic function is defined by
     #' \deqn{cf_X(t) = E_X[exp(xti)]}
     #' where X is the distribution and \eqn{E_X} is the expectation of the distribution X.
-    cf = function(t) {
+    #' @param ... Unused.
+    cf = function(t, ...) {
       (self$getParameterValue("qprob") +
         (self$getParameterValue("prob") * exp((0 + 1i) * t)))^self$getParameterValue("size")
     },
@@ -139,7 +146,8 @@ Binomial <- R6Class("Binomial",
     #' @description The probability generating function is defined by
     #' \deqn{pgf_X(z) = E_X[exp(z^x)]}
     #' where X is the distribution and \eqn{E_X} is the expectation of the distribution X.
-    pgf = function(z) {
+    #' @param ... Unused.
+    pgf = function(z, ...) {
       (self$getParameterValue("qprob") +
         (self$getParameterValue("prob") * z))^self$getParameterValue("size")
     },
