@@ -244,6 +244,28 @@ NumericVector C_SilvermanKernelPdf(NumericVector x, bool logp) {
   return ret;
 }
 
+// [[Rcpp::export]]
+NumericVector C_SilvermanKernelCdf(NumericVector x, bool lower, bool logp) {
+  NumericVector ret(x.size());
+
+  for (int i = 0; i < x.size(); i++){
+    if (x[i] <= 0) {
+      ret[i] = 0.5 * exp(x[i]/sqrt(2)) * cos(x[i]/sqrt(2));
+    } else {
+      ret[i] = 1 - (0.5 * exp(-x[i]/sqrt(2)) * cos(x[i]/sqrt(2)));
+    }
+
+    if (!lower) {
+      ret[i] = 1 - ret[i];
+    }
+    if (logp) {
+      ret[i] = log(ret[i]);
+    }
+  }
+
+  return ret;
+}
+
 // [[Rcpp::export]]
 NumericVector C_TriangularKernelPdf(NumericVector x, bool logp) {
   NumericVector ret(x.size());
@@ -335,6 +357,32 @@ NumericVector C_TricubeKernelPdf(NumericVector x, bool logp) {
   return ret;
 }
 
+// [[Rcpp::export]]
+NumericVector C_TricubeKernelCdf(NumericVector x, bool lower, bool logp) {
+  NumericVector ret(x.size());
+  for (int i = 0; i < x.size(); i++){
+    if (x[i] >= 1) {
+      ret[i] = 1;
+    } else if (x[i] <= -1) {
+      ret[i] = 0;
+    } else if ((x[i] > -1) & (x[i] <= 0)) {
+      ret[i] = (81 + 140 * x[i] + 150 * pow(x[i], 4) + 60 * pow(x[i], 7) + 14 * pow(x[i], 10)) /
+        162;
+    } else if ((x[i] > 0) & (x[i] <= 1)) {
+      ret[i] = (81 + 140 * x[i] - 105 * pow(x[i], 4) + 60 * pow(x[i], 7) - 14 * pow(x[i], 10)) /
+        162;
+    }
+
+    if (!lower) {
+      ret[i] = 1 - ret[i];
+    }
+    if (logp) {
+      ret[i] = log(ret[i]);
+    }
+  }
+  return ret;
+}
+
 // [[Rcpp::export]]
 NumericVector C_TriweightKernelPdf(NumericVector x, bool logp) {
   NumericVector ret(x.size());
